@@ -1,12 +1,13 @@
-from circuitsvis.activations import text_neuron_activations
+import circuitsvis
 import circuitsvis.utils.render
 import numpy as np
+from circuitsvis.activations import text_neuron_activations
 
 
 class TestTextNeuronActivations:
     def test_matches_snapshot(self, snapshot, monkeypatch):
-        # Monkeypatch uuid4 to always return the same uuid
         monkeypatch.setattr(circuitsvis.utils.render, "uuid4", lambda: "mock")
+        monkeypatch.setattr(circuitsvis, "__version__", "1.0.0")
 
         res = text_neuron_activations(
             tokens=["a", "b"],
